rem @echo off

set KRB_VERSION=1.17
set PKG_VERSION=-1
set KRB_WS_DIR=%~dp0
set KRB_GIT_DIR=%KRB_WS_DIR%\krb5
set KRB_SRC_DIR=%KRB_GIT_DIR%\src
set KRB_WIN32_BUNDLE_DIR=krb5-%KRB_VERSION%%PKG_VERSION%-win32ws
set KRB_WIN64_BUNDLE_DIR=krb5-%KRB_VERSION%%PKG_VERSION%-win64ws

set PATH=%PATH%;C:\Program Files (x86)\HTML Help Workshop

cd %KRB_WS_DIR% || goto error
if not exist %KRB_GIT_DIR%\.git (
    echo Cloning krb5 repository...
    rm -rf %KRB_GIT_DIR% || goto error
    git clone https://github.com/krb5/krb5.git || goto error
)

echo Cloning and checking out version %KRB_VERSION%...
cd %KRB_GIT_DIR%
git clean -dffx || goto error
git reset --hard HEAD || goto error
git checkout krb5-%KRB_VERSION% || goto error
cd %KRB_WS_DIR% || goto error

echo Removing bundle directories and archives...
rm -rf ^
    %KRB_WIN32_BUNDLE_DIR% ^
    %KRB_WIN64_BUNDLE_DIR% ^
    %KRB_WIN32_BUNDLE_DIR%.zip ^
    %KRB_WIN64_BUNDLE_DIR%.zip ^
    || goto error

echo Setting up Visual Studio 32-bit environment...
call "C:\Program Files (x86)\Microsoft Visual Studio\2017\Professional\VC\Auxiliary\Build\vcvars32.bat"

set KRB_INSTALL_DIR=%KRB_WS_DIR%\%KRB_WIN32_BUNDLE_DIR%\installed\x86-windows
mkdir %KRB_INSTALL_DIR% || goto error
cd %KRB_SRC_DIR% || goto error
nmake -f Makefile.in prep-windows || goto error
nmake NODEBUG=1 || goto error
nmake install NODEBUG=1 || goto error

cd %KRB_WS_DIR%
cp -vf build-krb5.bat README.wireshark %KRB_WIN32_BUNDLE_DIR% || goto error
7z a -tzip %KRB_WIN32_BUNDLE_DIR%.zip %KRB_WIN32_BUNDLE_DIR% || goto error

cd %KRB_GIT_DIR%
git clean -dffx || goto error
git reset --hard HEAD || goto error

echo Setting up Visual Studio 64-bit environment...
call "C:\Program Files (x86)\Microsoft Visual Studio\2017\Professional\VC\Auxiliary\Build\vcvars64.bat"

set KRB_INSTALL_DIR=%KRB_WS_DIR%\%KRB_WIN64_BUNDLE_DIR%\installed\x64-windows
mkdir %KRB_INSTALL_DIR% || goto error
cd %KRB_SRC_DIR% || goto error
nmake -f Makefile.in prep-windows || goto error
nmake NODEBUG=1 || goto error
nmake install NODEBUG=1 || goto error

cd %KRB_WS_DIR%
cp -vf build-krb5.bat README.wireshark %KRB_WIN64_BUNDLE_DIR% || goto error
7z a -tzip %KRB_WIN64_BUNDLE_DIR%.zip %KRB_WIN64_BUNDLE_DIR% || goto error

sha256sum %KRB_WIN32_BUNDLE_DIR%.zip %KRB_WIN64_BUNDLE_DIR%.zip

goto :EOF

:error
echo Error %errorlevel%
exit /b %errorlevel%